foo {
  // c-1: change-color(black,$blue:-1);
  c0: change-color(black,$blue:0);
  c1: change-color(black,$blue:1);
  c2: change-color(black,$blue:2);
  c3: change-color(black,$blue:3);
  c4: change-color(black,$blue:4);
  c5: change-color(black,$blue:5);
  c6: change-color(black,$blue:6);
  c7: change-color(black,$blue:7);
  c8: change-color(black,$blue:8);
  c9: change-color(black,$blue:9);
  c10: change-color(black,$blue:10);
  c11: change-color(black,$blue:11);
  c12: change-color(black,$blue:12);
  c13: change-color(black,$blue:13);
  c14: change-color(black,$blue:14);
  c15: change-color(black,$blue:15);
  c16: change-color(black,$blue:16);
  c17: change-color(black,$blue:17);
  c18: change-color(black,$blue:18);
  c19: change-color(black,$blue:19);
  c20: change-color(black,$blue:20);
  c21: change-color(black,$blue:21);
  c22: change-color(black,$blue:22);
  c23: change-color(black,$blue:23);
  c24: change-color(black,$blue:24);
  c25: change-color(black,$blue:25);
  c26: change-color(black,$blue:26);
  c27: change-color(black,$blue:27);
  c28: change-color(black,$blue:28);
  c29: change-color(black,$blue:29);
  c30: change-color(black,$blue:30);
  c31: change-color(black,$blue:31);
  c32: change-color(black,$blue:32);
  c33: change-color(black,$blue:33);
  c34: change-color(black,$blue:34);
  c35: change-color(black,$blue:35);
  c36: change-color(black,$blue:36);
  c37: change-color(black,$blue:37);
  c38: change-color(black,$blue:38);
  c39: change-color(black,$blue:39);
  c40: change-color(black,$blue:40);
  c41: change-color(black,$blue:41);
  c42: change-color(black,$blue:42);
  c43: change-color(black,$blue:43);
  c44: change-color(black,$blue:44);
  c45: change-color(black,$blue:45);
  c46: change-color(black,$blue:46);
  c47: change-color(black,$blue:47);
  c48: change-color(black,$blue:48);
  c49: change-color(black,$blue:49);
  c50: change-color(black,$blue:50);
  c51: change-color(black,$blue:51);
  c52: change-color(black,$blue:52);
  c53: change-color(black,$blue:53);
  c54: change-color(black,$blue:54);
  c55: change-color(black,$blue:55);
  c56: change-color(black,$blue:56);
  c57: change-color(black,$blue:57);
  c58: change-color(black,$blue:58);
  c59: change-color(black,$blue:59);
  c60: change-color(black,$blue:60);
  c61: change-color(black,$blue:61);
  c62: change-color(black,$blue:62);
  c63: change-color(black,$blue:63);
  c64: change-color(black,$blue:64);
  c65: change-color(black,$blue:65);
  c66: change-color(black,$blue:66);
  c67: change-color(black,$blue:67);
  c68: change-color(black,$blue:68);
  c69: change-color(black,$blue:69);
  c70: change-color(black,$blue:70);
  c71: change-color(black,$blue:71);
  c72: change-color(black,$blue:72);
  c73: change-color(black,$blue:73);
  c74: change-color(black,$blue:74);
  c75: change-color(black,$blue:75);
  c76: change-color(black,$blue:76);
  c77: change-color(black,$blue:77);
  c78: change-color(black,$blue:78);
  c79: change-color(black,$blue:79);
  c80: change-color(black,$blue:80);
  c81: change-color(black,$blue:81);
  c82: change-color(black,$blue:82);
  c83: change-color(black,$blue:83);
  c84: change-color(black,$blue:84);
  c85: change-color(black,$blue:85);
  c86: change-color(black,$blue:86);
  c87: change-color(black,$blue:87);
  c88: change-color(black,$blue:88);
  c89: change-color(black,$blue:89);
  c90: change-color(black,$blue:90);
  c91: change-color(black,$blue:91);
  c92: change-color(black,$blue:92);
  c93: change-color(black,$blue:93);
  c94: change-color(black,$blue:94);
  c95: change-color(black,$blue:95);
  c96: change-color(black,$blue:96);
  c97: change-color(black,$blue:97);
  c98: change-color(black,$blue:98);
  c99: change-color(black,$blue:99);
  c100: change-color(black,$blue:100);
  c101: change-color(black,$blue:101);
  c102: change-color(black,$blue:102);
  c103: change-color(black,$blue:103);
  c104: change-color(black,$blue:104);
  c105: change-color(black,$blue:105);
  c106: change-color(black,$blue:106);
  c107: change-color(black,$blue:107);
  c108: change-color(black,$blue:108);
  c109: change-color(black,$blue:109);
  c110: change-color(black,$blue:110);
  c111: change-color(black,$blue:111);
  c112: change-color(black,$blue:112);
  c113: change-color(black,$blue:113);
  c114: change-color(black,$blue:114);
  c115: change-color(black,$blue:115);
  c116: change-color(black,$blue:116);
  c117: change-color(black,$blue:117);
  c118: change-color(black,$blue:118);
  c119: change-color(black,$blue:119);
  c120: change-color(black,$blue:120);
  c121: change-color(black,$blue:121);
  c122: change-color(black,$blue:122);
  c123: change-color(black,$blue:123);
  c124: change-color(black,$blue:124);
  c125: change-color(black,$blue:125);
  c126: change-color(black,$blue:126);
  c127: change-color(black,$blue:127);
  c128: change-color(black,$blue:128);
  c129: change-color(black,$blue:129);
  c130: change-color(black,$blue:130);
  c131: change-color(black,$blue:131);
  c132: change-color(black,$blue:132);
  c133: change-color(black,$blue:133);
  c134: change-color(black,$blue:134);
  c135: change-color(black,$blue:135);
  c136: change-color(black,$blue:136);
  c137: change-color(black,$blue:137);
  c138: change-color(black,$blue:138);
  c139: change-color(black,$blue:139);
  c140: change-color(black,$blue:140);
  c141: change-color(black,$blue:141);
  c142: change-color(black,$blue:142);
  c143: change-color(black,$blue:143);
  c144: change-color(black,$blue:144);
  c145: change-color(black,$blue:145);
  c146: change-color(black,$blue:146);
  c147: change-color(black,$blue:147);
  c148: change-color(black,$blue:148);
  c149: change-color(black,$blue:149);
  c150: change-color(black,$blue:150);
  c151: change-color(black,$blue:151);
  c152: change-color(black,$blue:152);
  c153: change-color(black,$blue:153);
  c154: change-color(black,$blue:154);
  c155: change-color(black,$blue:155);
  c156: change-color(black,$blue:156);
  c157: change-color(black,$blue:157);
  c158: change-color(black,$blue:158);
  c159: change-color(black,$blue:159);
  c160: change-color(black,$blue:160);
  c161: change-color(black,$blue:161);
  c162: change-color(black,$blue:162);
  c163: change-color(black,$blue:163);
  c164: change-color(black,$blue:164);
  c165: change-color(black,$blue:165);
  c166: change-color(black,$blue:166);
  c167: change-color(black,$blue:167);
  c168: change-color(black,$blue:168);
  c169: change-color(black,$blue:169);
  c170: change-color(black,$blue:170);
  c171: change-color(black,$blue:171);
  c172: change-color(black,$blue:172);
  c173: change-color(black,$blue:173);
  c174: change-color(black,$blue:174);
  c175: change-color(black,$blue:175);
  c176: change-color(black,$blue:176);
  c177: change-color(black,$blue:177);
  c178: change-color(black,$blue:178);
  c179: change-color(black,$blue:179);
  c180: change-color(black,$blue:180);
  c181: change-color(black,$blue:181);
  c182: change-color(black,$blue:182);
  c183: change-color(black,$blue:183);
  c184: change-color(black,$blue:184);
  c185: change-color(black,$blue:185);
  c186: change-color(black,$blue:186);
  c187: change-color(black,$blue:187);
  c188: change-color(black,$blue:188);
  c189: change-color(black,$blue:189);
  c190: change-color(black,$blue:190);
  c191: change-color(black,$blue:191);
  c192: change-color(black,$blue:192);
  c193: change-color(black,$blue:193);
  c194: change-color(black,$blue:194);
  c195: change-color(black,$blue:195);
  c196: change-color(black,$blue:196);
  c197: change-color(black,$blue:197);
  c198: change-color(black,$blue:198);
  c199: change-color(black,$blue:199);
  c200: change-color(black,$blue:200);
  c201: change-color(black,$blue:201);
  c202: change-color(black,$blue:202);
  c203: change-color(black,$blue:203);
  c204: change-color(black,$blue:204);
  c205: change-color(black,$blue:205);
  c206: change-color(black,$blue:206);
  c207: change-color(black,$blue:207);
  c208: change-color(black,$blue:208);
  c209: change-color(black,$blue:209);
  c210: change-color(black,$blue:210);
  c211: change-color(black,$blue:211);
  c212: change-color(black,$blue:212);
  c213: change-color(black,$blue:213);
  c214: change-color(black,$blue:214);
  c215: change-color(black,$blue:215);
  c216: change-color(black,$blue:216);
  c217: change-color(black,$blue:217);
  c218: change-color(black,$blue:218);
  c219: change-color(black,$blue:219);
  c220: change-color(black,$blue:220);
  c221: change-color(black,$blue:221);
  c222: change-color(black,$blue:222);
  c223: change-color(black,$blue:223);
  c224: change-color(black,$blue:224);
  c225: change-color(black,$blue:225);
  c226: change-color(black,$blue:226);
  c227: change-color(black,$blue:227);
  c228: change-color(black,$blue:228);
  c229: change-color(black,$blue:229);
  c230: change-color(black,$blue:230);
  c231: change-color(black,$blue:231);
  c232: change-color(black,$blue:232);
  c233: change-color(black,$blue:233);
  c234: change-color(black,$blue:234);
  c235: change-color(black,$blue:235);
  c236: change-color(black,$blue:236);
  c237: change-color(black,$blue:237);
  c238: change-color(black,$blue:238);
  c239: change-color(black,$blue:239);
  c240: change-color(black,$blue:240);
  c241: change-color(black,$blue:241);
  c242: change-color(black,$blue:242);
  c243: change-color(black,$blue:243);
  c244: change-color(black,$blue:244);
  c245: change-color(black,$blue:245);
  c246: change-color(black,$blue:246);
  c247: change-color(black,$blue:247);
  c248: change-color(black,$blue:248);
  c249: change-color(black,$blue:249);
  c250: change-color(black,$blue:250);
  c251: change-color(black,$blue:251);
  c252: change-color(black,$blue:252);
  c253: change-color(black,$blue:253);
  c254: change-color(black,$blue:254);
  c255: change-color(black,$blue:255);
  // c256: change-color(black,$blue:256);
}
